@@ -397,12 +397,7 @@ let beautify_text =
       t
 
 let compute_graph data config =
-  let architectures =
-    List.map
-      (Benl_frontend.to_string "architectures")
-      (archs_list config)
-  in
-  let {src_map = sources; bin_map = binaries} = get_data ~cache:(Some data) is_affected architectures config in
+  let {src_map = sources; bin_map = binaries} = filter_affected data is_affected config in
   let src_of_bin : ([`binary], [`source] Package.Name.t) M.t =
     PAMap.fold
       (fun (name, _) pkg accu ->
