@@ -34,6 +34,7 @@ let clean = ref true
 let tconfig = ref None
 
 open Benl_types
+open Benl_modules
 open Benl_frontend
 
 let eval x =
@@ -518,6 +519,21 @@ let main args =
       in
       (* Read ben.cache *)
       let cache = read_cache (Benl_base.archs_list ()) in
+      (* Emit warnings for missing source packages *)
+      let () =
+        if !Benl_clflags.verbose || not !Benl_clflags.quiet then
+          let { Marshallable.src_map = srcs; Marshallable.bin_map = bins } = cache in
+          let missing = Hashtbl.create 43 in
+          PAMap.iter begin fun (name, arch) pkg ->
+            let src_name = Package.get "source" pkg in
+            let src = Package.Name.of_string src_name in
+            if not (Package.Map.mem src srcs || Hashtbl.mem missing (src, arch)) then
+              let () = Hashtbl.add missing (src, arch) () in
+              eprintf "warning: Source package %s is missing on %s!\n%!"
+                src_name
+                arch
+          end bins
+      in
       (* Compute data for each transition *)
       let results =
         Benl_parallel.map
